file_touch: Change file access and modification times

View source: R/file.R

file_touchR Documentation

Change file access and modification times

Description

Like the touch POSIX utility this will create the file if it does not exist.

Usage

file_touch(path, access_time = Sys.time(), modification_time = access_time)

Arguments

path

A character vector of one or more paths.

access_time, modification_time

The times to set, inputs will be coerced to POSIXct objects.

Examples


file_touch("foo", "2018-01-01")
file_info("foo")[c("access_time", "modification_time", "change_time", "birth_time")]


fs documentation built on March 24, 2026, 9:08 a.m.